@@ -3,7 +3,7 @@ package Net::ACME::X::InvalidParameter;
 use strict;
 use warnings;
 
-use parent qw( Net::ACME::X::StringBase );
+use parent qw( Net::ACME::X::HashBase );
 
 #named args required:
 #
